==========================
terraform_validate_patched
==========================

A temporary patched version of GPL versioned project terraform_validate that implements skipping of testing on resource and skipping of empty terraform files.


* Documentation:

Original Project
----------------

* https://github.com/elmundio87/terraform_validate
